@@ -1,6 +1,6 @@
 package Net::DNS::RR::MINFO;
 #
-# $Id: MINFO.pm,v 1.5 2003/09/03 04:41:50 ctriv Exp $
+# $Id: MINFO.pm,v 2.101 2004/01/04 04:31:10 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
@@ -8,17 +8,14 @@ use vars qw(@ISA $VERSION);
 use Net::DNS::Packet;
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 1.5 $)[1];
+$VERSION = (qw$Revision: 2.101 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my ($rmailbx, $emailbx);
-		($rmailbx, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
-		($emailbx, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"rmailbx"} = $rmailbx;
-		$self->{"emailbx"} = $emailbx;
+		($self->{"rmailbx"}, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
+		($self->{"emailbx"}, $offset) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
 
 	return bless $self, $class;
@@ -40,9 +37,9 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"rmailbx"}
+	return $self->{"rmailbx"}
 	       ? "$self->{rmailbx}. $self->{emailbx}."
-	       : "; no data";
+	       : '';
 }
 
 sub rr_rdata {
